@@ -3,7 +3,7 @@ package Git::Code::Review::Utilities;
 use strict;
 use warnings;
 
-our $VERSION = '2.0'; # VERSION
+our $VERSION = '2.1'; # VERSION
 
 # Utility Modules
 use CLI::Helpers qw(:all);
@@ -737,10 +737,10 @@ sub _get_commit_date {
 
     open(my $fh, "<", $path) or die "_get_commit_date() cannot open $path: $!";
     my $ISO=undef;
-    while( !$ISO ) {
+    while( !defined $ISO ) {
         local $_ = <$fh>;
         last unless defined $_;
-        next unless /^(Commit)Date:/;
+        next unless /^(Commit)?Date:/;
         $ISO = (split /\s+/)[1];
     }
     return $ISO;
@@ -832,7 +832,7 @@ Git::Code::Review::Utilities - Tools for performing code review using Git as the
 
 =head1 VERSION
 
-version 2.0
+version 2.1
 
 =head1 FUNCTIONS
 
